@@ -14,6 +14,9 @@ var group__private__api =
     [ "lirc_log.h", "lirc__log_8h.html", null ],
     [ "lirc_options.h", "lirc__options_8h.html", null ],
     [ "release.h", "release_8h.html", null ],
+    [ "util.h", "util_8h.html", null ],
+    [ "drop_root_cli", "group__private__api.html#ga24f983a41e2fccf1c7ba3ee4d69559a4", null ],
+    [ "drop_sudo_root", "group__private__api.html#ga08cad0a0a22fb34e70ef33be007e484d", null ],
     [ "free_config", "group__private__api.html#gaa55b7dcba60df4c178fd885eaf129288", null ],
     [ "read_config", "group__private__api.html#gaae645b840ccf7816a6dd37d53bc4325a", null ]
 ];
\ No newline at end of file
