@@ -3,12 +3,11 @@ var receive_8c =
     [ "RBUF_SIZE", "receive_8c.html#a3979138d69702d83185bef951f48dcd5", null ],
     [ "REC_SYNC", "receive_8c.html#aaa281087379bf91d7999ec8f15705929", null ],
     [ "rec_buffer_clear", "group__driver__api.html#gae96f4130a6ebac0570094820b39ae11c", null ],
-    [ "rec_buffer_init", "group__driver__api.html#gad2f7ee8888cb720cdf2be99b11f5230b", null ],
+    [ "rec_buffer_init", "group__driver__api.html#gabc294def4957afc161909b72e1348835", null ],
     [ "rec_buffer_reset_wptr", "group__driver__api.html#ga74266da334332e934158389894ddb7c4", null ],
     [ "rec_buffer_rewind", "group__driver__api.html#ga3367c6a318967cb750f67d95d43d3102", null ],
     [ "rec_buffer_set_logfile", "group__driver__api.html#ga0055fe8b9e15df2483fac31e79f8276a", null ],
+    [ "rec_set_update_mode", "group__driver__api.html#gaa491fcec2fc35512ff2964dc208edcca", null ],
     [ "receive_decode", "group__driver__api.html#gad89c025d8cc9f77d9d5597da2e420917", null ],
-    [ "waitfordata", "group__driver__api.html#gadcb46dccea6a4f82bebda46e51945819", null ],
-    [ "hw", "receive_8c.html#adf2cf82db144c1cac77571f3e8b9c14f", null ],
-    [ "last_remote", "group__driver__api.html#ga474c489cabdaae4546ca0ac26ec9cd87", null ]
+    [ "waitfordata", "group__driver__api.html#gadcb46dccea6a4f82bebda46e51945819", null ]
 ];
\ No newline at end of file
