@@ -9,7 +9,9 @@
  */
 
 #include	<stdio.h>
-#include 	"driver.h"
+#include	"driver.h"
+#include	"config.h"
+#include	"lirc_log.h"
 
 /**
  * The global driver data that drivers etc are accessing.
@@ -18,7 +20,7 @@
 struct driver drv;
 
 /** sscanf format to parse option_t. */
-const char*  const  OPTION_FMT  = "%32s%64s";
+const char* const OPTION_FMT = "%32s%64s";
 
 /** Read-only access to drv for client code. */
 const struct driver const* curr_driver = &drv;
@@ -26,12 +28,19 @@ const struct driver const* curr_driver = &drv;
 int default_open(const char* path)
 {
 	static char buff[128];
-	strncpy(buff, path, sizeof(buff));
-	drv.device = buff;
+
+	if (path == NULL) {
+		if (drv.device == NULL)
+			drv.device = LIRC_DRIVER_DEVICE;
+	} else {
+		strncpy(buff, path, sizeof(buff) - 1);
+		drv.device = buff;
+	}
+	logprintf(LIRC_INFO, "Initial device: %s", drv.device);
 	return 0;
 }
 
-int default_close()
+int default_close(void)
 {
 	return 0;
 }
@@ -49,11 +58,12 @@ int drv_handle_options(const char* options)
 	struct option_t option;
 	int found;
 	char* colon;
+	int result;
 
 	s = alloca(strlen(options) + 1);
 	strcpy(s, options);
-	for (token = strtok(s, "|"); token != NULL; token = strtok(NULL, "|")){
-		colon=strstr(token, ":");
+	for (token = strtok(s, "|"); token != NULL; token = strtok(NULL, "|")) {
+		colon = strstr(token, ":");
 		if (colon == NULL)
 			return DRV_ERR_BAD_OPTION;
 		*colon = ' ';
@@ -62,9 +72,9 @@ int drv_handle_options(const char* options)
 			return DRV_ERR_BAD_OPTION;
 		if (!curr_driver->drvctl_func)
 			continue;
-		curr_driver->drvctl_func(DRVCTL_SET_OPTION, (void*) &option);
+		result = curr_driver->drvctl_func(DRVCTL_SET_OPTION, (void*) &option);
+		if (result != 0)
+			return result;
 	}
 	return 0;
 }
-
-
